@@ -1,23 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2007 by Joris Guisson and Ivan Vasic                    *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2007 Ivan Vasic <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "view.h"
 
@@ -540,7 +525,7 @@ void View::previewTorrents()
     getSelection(sel);
     for (bt::TorrentInterface *tc : qAsConst(sel)) {
         if (tc->readyForPreview() && !tc->getStats().multi_file_torrent) {
-            new KRun(QUrl::fromLocalFile(tc->getStats().output_path), 0, true);
+            new KRun(QUrl::fromLocalFile(tc->getStats().output_path), nullptr, true);
         }
     }
 }
@@ -551,9 +536,9 @@ void View::openDataDir()
     getSelection(sel);
     for (bt::TorrentInterface *tc : qAsConst(sel)) {
         if (tc->getStats().multi_file_torrent)
-            new KRun(QUrl::fromLocalFile(tc->getStats().output_path), 0, true);
+            new KRun(QUrl::fromLocalFile(tc->getStats().output_path), nullptr, true);
         else
-            new KRun(QUrl::fromLocalFile(tc->getDataDir()), 0, true);
+            new KRun(QUrl::fromLocalFile(tc->getDataDir()), nullptr, true);
     }
 }
 
@@ -562,7 +547,7 @@ void View::openTorDir()
     QList<bt::TorrentInterface *> sel;
     getSelection(sel);
     for (bt::TorrentInterface *tc : qAsConst(sel)) {
-        new KRun(QUrl::fromLocalFile(tc->getTorDir()), 0, true);
+        new KRun(QUrl::fromLocalFile(tc->getTorDir()), nullptr, true);
     }
 }
 
@@ -734,9 +719,9 @@ void View::onDoubleClicked(const QModelIndex &index)
     bt::TorrentInterface *tc = model->torrentFromIndex(index);
     if (tc) {
         if (tc->getStats().multi_file_torrent)
-            new KRun(QUrl::fromLocalFile(tc->getStats().output_path), 0, true);
+            new KRun(QUrl::fromLocalFile(tc->getStats().output_path), nullptr, true);
         else
-            new KRun(QUrl::fromLocalFile(tc->getDataDir()), 0, true);
+            new KRun(QUrl::fromLocalFile(tc->getDataDir()), nullptr, true);
     }
 }
 
@@ -787,7 +772,7 @@ void View::onGroupRenamed(Group *g)
 void View::addToGroupItemTriggered()
 {
     QAction *s = (QAction *)sender();
-    Group *g = 0;
+    Group *g = nullptr;
     QMap<Group *, QAction *>::iterator j = group_actions.begin();
     while (j != group_actions.end() && !g) {
         if (j.value() == s)
@@ -838,7 +823,7 @@ void View::speedLimits()
 {
     QList<bt::TorrentInterface *> sel;
     getSelection(sel);
-    SpeedLimitsDlg dlg(sel.count() > 0 ? sel.front() : 0, core, gui->getMainWindow());
+    SpeedLimitsDlg dlg(sel.count() > 0 ? sel.front() : nullptr, core, gui->getMainWindow());
     dlg.exec();
 }
 
