@@ -315,6 +315,12 @@ void ViewDelegate::hideExtender(bt::TorrentInterface *tc)
 
 void ViewDelegate::paintProgressBar(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
+    // first filling the background as if it was an empty cell
+    QStyleOptionViewItem dummyOption = option;
+    dummyOption.text = QLatin1String("");
+    dummyOption.index = QModelIndex();
+    QStyledItemDelegate::paint(painter, dummyOption, QModelIndex());
+
     int progress = index.data().toInt();
 
     QStyleOptionProgressBar progressBarOption;
@@ -328,6 +334,10 @@ void ViewDelegate::paintProgressBar(QPainter *painter, const QStyleOptionViewIte
     progressBarOption.textVisible = true;
     progressBarOption.direction = option.direction;
 
+    // ProgressBars have no concept of being selected (AFAIK), so the color of its text has to be changed manually
+    if (option.state & QStyle::State_Selected)
+        progressBarOption.palette.setColor(QPalette::Active, QPalette::WindowText, option.palette.highlightedText().color());
+
     QApplication::style()->drawControl(QStyle::CE_ProgressBar, &progressBarOption, painter);
 }
 
