@@ -7,12 +7,11 @@
 
 namespace kt
 {
-Plugin::Plugin(QObject *parent)
+Plugin::Plugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
     : KParts::Plugin(parent)
 {
-    core = nullptr;
-    gui = nullptr;
-    loaded = false;
+    setMetaData(data);
+    Q_UNUSED(args)
 }
 
 Plugin::~Plugin()
