@@ -36,7 +36,7 @@ class KTCORE_EXPORT Plugin : public KParts::Plugin
 {
     Q_OBJECT
 public:
-    Plugin(QObject *parent);
+    Plugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
     ~Plugin() override;
 
     /**
@@ -118,8 +118,10 @@ public:
         return loaded;
     }
 
-    /// Check whether the plugin matches the version of KT
-    virtual bool versionCheck(const QString &version) const = 0;
+    void setIsLoaded(bool isLoaded)
+    {
+        loaded = isLoaded;
+    }
 
     /// Returns the name of the parent part the GUI of the plugin should be created in
     virtual QString parentPart() const
@@ -128,11 +130,9 @@ public:
     }
 
 private:
-    CoreInterface *core;
-    GUIInterface *gui;
-    bool loaded;
-
-    friend class PluginManager;
+    CoreInterface *core = nullptr;
+    GUIInterface *gui = nullptr;
+    bool loaded = false;
 };
 
 }
