@@ -10,7 +10,6 @@
 
 #include <KLocalizedString>
 #include <KPluginMetaData>
-#include <KSharedConfig>
 
 #include "pluginactivity.h"
 #include <interfaces/guiinterface.h>
@@ -40,23 +39,6 @@ PluginManager::~PluginManager()
 void PluginManager::loadPluginList()
 {
     pluginsMetaData = KPluginLoader::findPlugins(QStringLiteral("ktorrent"));
-    if (pluginsMetaData.isEmpty()) {
-        // simple workaround for the situation i have in debian --Nick
-        QStringList paths = QCoreApplication::libraryPaths();
-        if (paths.isEmpty())
-            paths << QLatin1String("/usr/lib/x86_64-linux-gnu/plugins");
-
-        QCoreApplication::addLibraryPath(paths.first().remove(QLatin1String("qt5/")));
-        pluginsMetaData = KPluginLoader::findPlugins(QStringLiteral("ktorrent"));
-    }
-
-    for (const KPluginMetaData &module : qAsConst(pluginsMetaData)) {
-        KPluginInfo pi(module);
-        pi.setConfig(KSharedConfig::openConfig()->group(pi.pluginName()));
-        pi.load();
-
-        plugins << pi;
-    }
 
     if (!prefpage) {
         prefpage = new PluginActivity(this);
@@ -68,56 +50,51 @@ void PluginManager::loadPluginList()
     prefpage->update();
 }
 
+inline bool isPluginEnabled(const KPluginMetaData &data)
+{
+    return KSharedConfig::openConfig()->group(data.pluginId()).readEntry(data.pluginId() + QLatin1String("Enabled"), data.isEnabledByDefault());
+}
+
 void PluginManager::loadPlugins()
 {
     int idx = 0;
-    for (auto i = plugins.begin(); i != plugins.end(); i++) {
-        KPluginInfo &pi = *i;
-        if (loaded.contains(idx) && !pi.isPluginEnabled()) {
+    for (const KPluginMetaData &data : qAsConst(pluginsMetaData)) {
+        if (loaded.contains(idx) && !isPluginEnabled(data)) {
             // unload it
-            unload(pi, idx);
-            pi.save();
-        } else if (!loaded.contains(idx) && pi.isPluginEnabled()) {
+            unload(data, idx);
+        } else if (!loaded.contains(idx) && isPluginEnabled(data)) {
             // load it
-            load(pi, idx);
-            pi.save();
+            load(data, idx);
         }
         idx++;
     }
 }
 
-void PluginManager::load(const KPluginInfo &pi, int idx)
+void PluginManager::load(const KPluginMetaData &data, int idx)
 {
-    Q_UNUSED(pi)
-    KPluginLoader loader(pluginsMetaData.at(idx).fileName());
+    KPluginLoader loader(data.fileName());
     KPluginFactory *factory = loader.factory();
     if (!factory)
         return;
 
+    factory->setMetaData(data);
     Plugin *plugin = factory->create<kt::Plugin>();
     if (!plugin) {
         Out(SYS_GEN | LOG_NOTICE) << QStringLiteral("Creating instance of plugin %1 failed !").arg(pluginsMetaData.at(idx).fileName()) << endl;
         return;
     }
 
-    if (!plugin->versionCheck(QStringLiteral(VERSION))) {
-        Out(SYS_GEN | LOG_NOTICE) << QStringLiteral("Plugin %1 version does not match KTorrent version, unloading it.").arg(pluginsMetaData.at(idx).fileName())
-                                  << endl;
-
-        delete plugin;
-    } else {
-        plugin->setCore(core);
-        plugin->setGUI(gui);
-        plugin->load();
-        gui->mergePluginGui(plugin);
-        plugin->loaded = true;
-        loaded.insert(idx, plugin, true);
-    }
+    plugin->setCore(core);
+    plugin->setGUI(gui);
+    plugin->load();
+    gui->mergePluginGui(plugin);
+    plugin->setIsLoaded(true);
+    loaded.insert(idx, plugin, true);
 }
 
-void PluginManager::unload(const KPluginInfo &pi, int idx)
+void PluginManager::unload(const KPluginMetaData &data, int idx)
 {
-    Q_UNUSED(pi)
+    Q_UNUSED(data)
 
     Plugin *p = loaded.find(idx);
     if (!p)
@@ -137,7 +114,7 @@ void PluginManager::unload(const KPluginInfo &pi, int idx)
 
     gui->removePluginGui(p);
     p->unload();
-    p->loaded = false;
+    p->setIsLoaded(false);
     loaded.erase(idx);
 }
 
@@ -166,7 +143,7 @@ void PluginManager::unloadAll()
         Plugin *p = i->second;
         gui->removePluginGui(p);
         p->unload();
-        p->loaded = false;
+        p->setIsLoaded(false);
         i++;
     }
     loaded.clear();
