@@ -1,22 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2014 by Juan Palacios                                   *
- *   jpalaciosdev@gmail.com                                                *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2014 Juan Palacios <jpalaciosdev@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "magnetmanager.h"
 
@@ -161,7 +146,7 @@ void MagnetManager::removeMagnets(bt::Uint32 idx, bt::Uint32 count)
         return;
 
     while (count > 0 && idx < (Uint32)magnetHashes.size()) {
-        MagnetDownloader *md = 0;
+        MagnetDownloader *md = nullptr;
         Uint32 magnetQueueSize = magnetQueue.size();
         if (idx < magnetQueueSize) {
             md = magnetQueue.at(idx);
@@ -369,7 +354,7 @@ void MagnetManager::loadMagnets(const QString &file)
         return;
 
     BDecoder decoder(magnet_data, 0, false);
-    BNode *node = 0;
+    BNode *node = nullptr;
     try {
         node = decoder.decode();
         if (!node || node->getType() != BNode::LIST)
@@ -378,17 +363,17 @@ void MagnetManager::loadMagnets(const QString &file)
         BListNode *ml = (BListNode *)node;
         for (Uint32 i = 0; i < ml->getNumChildren(); i++) {
             BDictNode *dict = ml->getDict(i);
-            MagnetLink mlink(dict->getString(QByteArrayLiteral("magnet"), 0));
+            MagnetLink mlink(dict->getString(QByteArrayLiteral("magnet"), nullptr));
             MagnetLinkLoadOptions options;
             bool stopped = dict->getInt(QByteArrayLiteral("stopped")) == 1;
             options.silently = dict->getInt(QByteArrayLiteral("silent")) == 1;
 
             if (dict->keys().contains("group"))
-                options.group = dict->getString(QByteArrayLiteral("group"), 0);
+                options.group = dict->getString(QByteArrayLiteral("group"), nullptr);
             if (dict->keys().contains("location"))
-                options.location = dict->getString(QByteArrayLiteral("location"), 0);
+                options.location = dict->getString(QByteArrayLiteral("location"), nullptr);
             if (dict->keys().contains("move_on_completion"))
-                options.move_on_completion = dict->getString(QByteArrayLiteral("move_on_completion"), 0);
+                options.move_on_completion = dict->getString(QByteArrayLiteral("move_on_completion"), nullptr);
 
             addMagnet(mlink, options, stopped);
         }
