@@ -1,23 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2007 by Joris Guisson and Ivan Vasic                    *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2007 Ivan Vasic <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "torrentfiletreemodel.h"
 
@@ -451,7 +436,7 @@ QModelIndex TorrentFileTreeModel::index(int row, int column, const QModelIndex &
     if (!tc || row < 0 || row >= rowCount(parent) || column < 0 || column >= columnCount(parent))
         return QModelIndex();
 
-    Node *p = 0;
+    Node *p = nullptr;
 
     if (!parent.isValid())
         return createIndex(row, column, root);
@@ -661,7 +646,7 @@ void TorrentFileTreeModel::loadExpandedState(QSortFilterProxyModel *pm, QTreeVie
         return;
 
     BDecoder dec(state, false, 0);
-    BNode *n = 0;
+    BNode *n = nullptr;
     try {
         n = dec.decode();
         if (n && n->getType() == BNode::DICT) {
@@ -676,11 +661,11 @@ void TorrentFileTreeModel::loadExpandedState(QSortFilterProxyModel *pm, QTreeVie
 bt::TorrentFileInterface *TorrentFileTreeModel::indexToFile(const QModelIndex &idx)
 {
     if (!tc || !idx.isValid())
-        return 0;
+        return nullptr;
 
     Node *n = (Node *)idx.internalPointer();
     if (!n)
-        return 0;
+        return nullptr;
 
     return n->file;
 }
