@@ -1,23 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2007 by Joris Guisson and Ivan Vasic                    *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2007 Ivan Vasic <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <KLocalizedString>
 #include <QFile>
@@ -133,7 +118,7 @@ void Schedule::load(const QString &file)
 
     QByteArray data = fptr.readAll();
     BDecoder dec(data, false, 0);
-    BNode *node = 0;
+    BNode *node = nullptr;
     try {
         node = dec.decode();
     } catch (bt::Error &err) {
@@ -319,7 +304,7 @@ ScheduleItem *Schedule::getCurrentItem(const QDateTime &now)
             return i;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 int Schedule::getTimeToNextScheduleEvent(const QDateTime &now)
