@@ -1,22 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "fileview.h"
 
@@ -95,9 +80,9 @@ FileView::FileView(QWidget *parent)
     proxy_model = new TreeFilterModel(this);
     proxy_model->setSortRole(Qt::UserRole);
     if (show_list_of_files)
-        model = new IWFileListModel(0, this);
+        model = new IWFileListModel(nullptr, this);
     else
-        model = new IWFileTreeModel(0, this);
+        model = new IWFileTreeModel(nullptr, this);
     proxy_model->setSourceModel(model);
     view->setModel(proxy_model);
 
@@ -161,7 +146,7 @@ void FileView::changeTC(bt::TorrentInterface *tc)
         expanded_state_map[curr_tc.data()] = model->saveExpandedState(proxy_model, view);
 
     curr_tc = tc;
-    setEnabled(tc != 0);
+    setEnabled(tc != nullptr);
     model->changeTorrent(tc);
     if (tc) {
         connect(tc, &bt::TorrentInterface::missingFilesMarkedDND, this, &FileView::onMissingFileMarkedDND);
@@ -331,7 +316,7 @@ void FileView::deleteFiles()
                         "You will lose all data in these files, are you sure you want to do this?",
                         n);
 
-    if (KMessageBox::warningYesNo(0, msg) == KMessageBox::Yes)
+    if (KMessageBox::warningYesNo(nullptr, msg) == KMessageBox::Yes)
         changePriority(EXCLUDED);
 }
 
@@ -529,12 +514,12 @@ void FileView::setShowListOfFiles(bool on)
     show_list_of_files = on;
     if (!curr_tc) {
         // no torrent, but still need to change the model
-        proxy_model->setSourceModel(0);
+        proxy_model->setSourceModel(nullptr);
         delete model;
         if (show_list_of_files)
-            model = new IWFileListModel(0, this);
+            model = new IWFileListModel(nullptr, this);
         else
-            model = new IWFileTreeModel(0, this);
+            model = new IWFileTreeModel(nullptr, this);
         proxy_model->setSourceModel(model);
         view->header()->restoreState(header_state);
         return;
@@ -544,9 +529,9 @@ void FileView::setShowListOfFiles(bool on)
     if (on)
         expanded_state_map[tc] = model->saveExpandedState(proxy_model, view);
 
-    proxy_model->setSourceModel(0);
+    proxy_model->setSourceModel(nullptr);
     delete model;
-    model = 0;
+    model = nullptr;
 
     if (show_list_of_files)
         model = new IWFileListModel(tc, this);
