@@ -1,23 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2006-2009 by Joris Guisson, Ivan Vasic                  *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006-2009 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2006-2009 Ivan Vasic <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "trackerview.h"
 
@@ -92,7 +77,7 @@ TrackerView::TrackerView(QWidget *parent)
     });
 
     setEnabled(false);
-    torrentChanged(0);
+    torrentChanged(nullptr);
 }
 
 TrackerView::~TrackerView()
@@ -141,9 +126,9 @@ void TrackerView::addClicked()
     }
 
     if (dupes.size() == 1)
-        KMessageBox::sorry(0, i18n("There already is a tracker named <b>%1</b>.", dupes.front().toDisplayString()));
+        KMessageBox::sorry(nullptr, i18n("There already is a tracker named <b>%1</b>.", dupes.front().toDisplayString()));
     else if (dupes.size() > 1)
-        KMessageBox::informationList(0, i18n("The following duplicate trackers were not added:"), QUrl::toStringList(dupes));
+        KMessageBox::informationList(nullptr, i18n("The following duplicate trackers were not added:"), QUrl::toStringList(dupes));
 
     if (!tl.isEmpty())
         model->addTrackers(tl);
@@ -206,7 +191,7 @@ void TrackerView::changeTC(TorrentInterface *ti)
     if (tc.data() == ti)
         return;
 
-    setEnabled(ti != 0);
+    setEnabled(ti != nullptr);
     torrentChanged(ti);
     update();
 
@@ -231,7 +216,7 @@ void TrackerView::torrentChanged(TorrentInterface *ti)
         m_restore_defaults->setEnabled(false);
         m_change_tracker->setEnabled(false);
         m_scrape->setEnabled(false);
-        model->changeTC(0);
+        model->changeTC(nullptr);
     } else {
         m_add_tracker->setEnabled(true);
         m_remove_tracker->setEnabled(true);
