@@ -1,23 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2008 by Joris Guisson and Ivan Vasic                    *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2008 Ivan Vasic <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "webseedstab.h"
 
@@ -68,12 +53,12 @@ void WebSeedsTab::changeTC(bt::TorrentInterface *tc)
 {
     curr_tc = tc;
     model->changeTC(tc);
-    m_add->setEnabled(tc != 0);
-    m_remove->setEnabled(tc != 0);
-    m_webseed_list->setEnabled(tc != 0);
-    m_webseed->setEnabled(tc != 0);
-    m_enable_all->setEnabled(tc != 0);
-    m_disable_all->setEnabled(tc != 0);
+    m_add->setEnabled(tc != nullptr);
+    m_remove->setEnabled(tc != nullptr);
+    m_webseed_list->setEnabled(tc != nullptr);
+    m_webseed->setEnabled(tc != nullptr);
+    m_enable_all->setEnabled(tc != nullptr);
+    m_disable_all->setEnabled(tc != nullptr);
     onWebSeedTextChanged(m_webseed->text());
 
     // see if we need to enable or disable the remove button
