@@ -29,11 +29,9 @@ K_PLUGIN_FACTORY_WITH_JSON(ktorrent_scanfolder, "ktorrent_scanfolder.json", regi
 
 namespace kt
 {
-ScanFolderPlugin::ScanFolderPlugin(QObject *parent, const QVariantList &args)
-    : Plugin(parent)
-    , tlq(nullptr)
+ScanFolderPlugin::ScanFolderPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : Plugin(parent, data, args)
 {
-    Q_UNUSED(args);
 }
 
 ScanFolderPlugin::~ScanFolderPlugin()
@@ -88,10 +86,6 @@ void ScanFolderPlugin::updateScanFolders()
     scanner->setFolderList(folders);
 }
 
-bool ScanFolderPlugin::versionCheck(const QString &version) const
-{
-    return version == QStringLiteral(VERSION);
-}
 }
 
 #include "scanfolderplugin.moc"
