@@ -1,22 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2020 by Alexander Trufanov                              *
- *   trufanovan@gmail.com                                                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2020 Alexander Trufanov <trufanovan@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "scanforlostfileswidget.h"
 #include "scanforlostfilesplugin.h"
@@ -65,7 +50,7 @@ ScanForLostFilesWidget::ScanForLostFilesWidget(ScanForLostFilesPlugin *plugin, Q
 
     connect(actionOpen_file, &QAction::triggered, [=]() {
         QModelIndex index = treeView->currentIndex();
-        new KRun(QUrl::fromLocalFile(m_model->filePath(m_proxy->mapToSource(index))), 0, true);
+        new KRun(QUrl::fromLocalFile(m_model->filePath(m_proxy->mapToSource(index))), nullptr, true);
     });
 
     treeView->setSortingEnabled(true);
@@ -197,7 +182,7 @@ void ScanForLostFilesWidget::on_actionDelete_on_disk_triggered()
                         n);
 
     QList<QUrl> to_del;
-    if (KMessageBox::warningYesNo(0, msg) == KMessageBox::Yes) {
+    if (KMessageBox::warningYesNo(nullptr, msg) == KMessageBox::Yes) {
         for (const QModelIndex &m : sel) {
             to_del.append(QUrl::fromLocalFile(m_model->filePath(m_proxy->mapToSource(m))));
         }
