@@ -1,22 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2009 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "searchactivity.h"
 
@@ -146,7 +131,7 @@ void SearchActivity::loadCurrentSearches()
 
     QByteArray data = fptr.readAll();
     bt::BDecoder dec(data, false, 0);
-    bt::BListNode *search_list = 0;
+    bt::BListNode *search_list = nullptr;
     try {
         search_list = dec.decodeList();
         if (!search_list)
@@ -157,10 +142,10 @@ void SearchActivity::loadCurrentSearches()
             if (!dict)
                 continue;
 
-            QString text = dict->getString("TEXT", 0);
-            QString sbtext = dict->getString("SBTEXT", 0);
+            QString text = dict->getString("TEXT", nullptr);
+            QString sbtext = dict->getString("SBTEXT", nullptr);
             int engine = dict->getInt("ENGINE");
-            QUrl url = QUrl(dict->getString("URL", 0));
+            QUrl url = QUrl(dict->getString("URL", nullptr));
 
             SearchWidget *search = newSearchWidget(text);
             search->restore(url, text, sbtext, engine);
