@@ -1,23 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2005-2007 by Joris Guisson, Ivan Vasic                  *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005-2007 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2005-2007 Ivan Vasic <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "searchwidget.h"
 
@@ -99,7 +84,7 @@ SearchWidget::~SearchWidget()
 {
     if (prog) {
         sp->getGUI()->getStatusBar()->removeProgressBar(prog);
-        prog = 0;
+        prog = nullptr;
     }
 }
 
@@ -194,7 +179,7 @@ void SearchWidget::loadFinished(bool ok)
 
     if (prog) {
         sp->getGUI()->getStatusBar()->removeProgressBar(prog);
-        prog = 0;
+        prog = nullptr;
     }
 }
 
@@ -209,7 +194,7 @@ void SearchWidget::magnetUrl(const QUrl &magnet_url)
 
 void SearchWidget::downloadTorrentFile(QWebEngineDownloadItem *download)
 {
-    int ret = KMessageBox::questionYesNoCancel(0,
+    int ret = KMessageBox::questionYesNoCancel(nullptr,
 
                                                i18n("Do you want to download or save the torrent?"),
                                                i18n("Download Torrent"),
