@@ -1,23 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2008 by Joris Guisson and Ivan Vasic                    *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2008 Ivan Vasic <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <QApplication>
 #include <QColor>
@@ -126,11 +111,11 @@ void FeedWidget::setFeed(Feed *f)
     if (feed) {
         disconnect(feed, &Feed::updated, this, &FeedWidget::updated);
         disconnect(feed, &Feed::feedRenamed, this, &FeedWidget::onFeedRenamed);
-        feed = 0;
+        feed = nullptr;
     }
 
     feed = f;
-    setEnabled(feed != 0);
+    setEnabled(feed != nullptr);
     model->setCurrentFeed(f);
     if (feed) {
         connect(feed, &Feed::updated, this, &FeedWidget::updated);
@@ -187,7 +172,7 @@ void FeedWidget::cookiesClicked()
 
     bool ok = false;
     QString cookie = feed->authenticationCookie();
-    QString nc = QInputDialog::getText(0, i18n("Authentication Cookie"), i18n("Enter the new authentication cookie"), QLineEdit::Normal, cookie, &ok);
+    QString nc = QInputDialog::getText(nullptr, i18n("Authentication Cookie"), i18n("Enter the new authentication cookie"), QLineEdit::Normal, cookie, &ok);
     if (ok) {
         feed->setAuthenticationCookie(nc);
         feed->save();
