@@ -22,11 +22,9 @@ using namespace bt;
 
 namespace kt
 {
-SyndicationPlugin::SyndicationPlugin(QObject *parent, const QVariantList &args)
-    : Plugin(parent)
-    , add_feed(nullptr)
+SyndicationPlugin::SyndicationPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : Plugin(parent, data, args)
 {
-    Q_UNUSED(args);
     setupActions();
     //  setXMLFile("ktsyndicationpluginui.rc");
     LogSystemManager::instance().registerSystem(i18n("Syndication"), SYS_SYN);
@@ -37,11 +35,6 @@ SyndicationPlugin::~SyndicationPlugin()
     LogSystemManager::instance().unregisterSystem(i18n("Syndication"));
 }
 
-bool SyndicationPlugin::versionCheck(const QString &version) const
-{
-    return version == QStringLiteral(VERSION);
-}
-
 void SyndicationPlugin::load()
 {
     activity = new SyndicationActivity(this, nullptr);
